@@ -46,4 +46,12 @@ escape_html <- function(x) {
   x
 }
 
+unescape_html <- function(x) {
+  x <- gsub("&lt;", "<", x)
+  x <- gsub("&gt;", ">", x)
+  x <- gsub("&amp;", "&", x)
+  x
+}
+
+
 strip_html_tags <- function(x) gsub("<.*?>", "", x)
