@@ -1,6 +1,7 @@
 rd2ex <- function(x, ...) {
-  x <- rd_text(paste0("\\examples{", x, "}"), fragment = FALSE)
-  x <- flatten_ex(x[[1]], ...)
+  x <- rd_text(paste0("\\examples{", x, "}"), fragment = FALSE)[[1]]
+  x <- process_conditional_examples(x)
+  x <- flatten_ex(x, ...)
 
   if (grepl("\n", x)) {
     strsplit(x, "\n")[[1]]
@@ -25,6 +26,7 @@ run_examples <- function(x,
     x <- x[-1]
   }
 
+  x <- process_conditional_examples(x)
   code <- flatten_ex(x, run_dont_run = run_dont_run)
 
   if (!can_parse(code)) {
@@ -39,14 +41,76 @@ run_examples <- function(x,
   }
 }
 
-highlight_examples <- function(x, topic, env = globalenv()) {
+process_conditional_examples <- function(rd) {
+  if (is.list(rd)) {
+    which_exif <- which(purrr::map_lgl(rd, function(x) {
+      "tag_dontshow" %in% class(x) &&
+        is.character(x[[1]]) &&
+        grepl("# examplesIf$", x[[1]])
+    }))
+    if (length(which_exif) == 0) return(rd)
+    if (length(which_exif) %% 2 != 0) stop("@examplesIf error, not closed?")
+    remove <- integer()
+    modes <- c("begin", "end")
+    for (idx in which_exif) {
+      if (rd[[idx]] != "}) # examplesIf") {
+        # Start of @examplesIf
+        if (modes[1] == "end") stop("@examplesIf error, not closed?")
+        cond_expr <- parse(text = paste0(rd[[idx]], "\n})"))[[1]][[2]]
+        cond <- eval(cond_expr)
+        if (isTRUE(cond)) {
+          remove <- c(remove, idx, idx + 1L)
+        } else {
+          is_false <- deparse(cond_expr) == "FALSE"
+          if (!is_false) {
+            new_cond <- paste0("if (FALSE) { # ", deparse(cond_expr))
+            warning(
+              "@examplesIf condition `",
+              deparse(cond_expr),
+              "` is FALSE"
+            )
+          } else {
+            new_cond <- "if (FALSE) {"
+          }
+          rd[[idx]] <- structure(list(new_cond), class = c("RCODE", "tag"))
+        }
+      } else {
+        # End of @examplesIf
+        if (modes[1] == "begin") stop("@examplesIf error, closed twice?")
+        if (isTRUE(cond)) {
+          remove <- c(remove, idx, idx + 1L)
+        } else {
+          rd[[idx]] <- structure(list("}"), class = c("RCODE", "tag"))
+        }
+      }
+      modes <- rev(modes)
+    }
+    if (length(remove)) rd <- rd[-remove]
+    rd
+
+  } else {
+    rd
+  }
+}
+
+highlight_examples <- function(code, topic, env = globalenv()) {
+  bg <- context_get("figures")$bg %||% NA
   withr::local_options(list(
-    crayon.enabled = getOption("crayon.enabled", crayon::has_color()),
-    crayon.colors = getOption("crayon.colors", crayon::num_colors())
+    crayon.enabled = TRUE,
+    crayon.colors = 256,
+    device = function(...) ragg::agg_png(..., bg = bg)
   ))
 
-  expr <- evaluate::evaluate(x, child_env(env), new_device = TRUE)
-  replay_html(expr, topic = topic, obj_id = unique_id())
+  fig_save_topic <- function(plot, id) {
+    name <- paste0(topic, "-", id)
+    do.call(fig_save, c(list(plot, name), context_get("figures")))
+  }
+
+  downlit::evaluate_and_highlight(
+    code,
+    fig_save = fig_save_topic,
+    env = child_env(env)
+  )
 }
 
 # as_example --------------------------------------------------------------
@@ -144,12 +208,3 @@ can_parse <- function(x) {
     TRUE
   }, error = function(e) FALSE)
 }
-
-unique_id <- function() {
-  i <- 0
-
-  function() {
-    i <<- i + 1
-    i
-  }
-}
