@@ -2,7 +2,7 @@ test_that("can generate three types of row", {
   ref <- list(
     list(title = "A"),
     list(subtitle = "B"),
-    list(contents = c("a", "b", "c"))
+    list(contents = c("a", "b", "c", "?"))
   )
   meta <- list(reference = ref)
   pkg <- as_pkgdown(test_path("assets/reference"), override = meta)
@@ -23,5 +23,5 @@ test_that("warns if missing topics", {
 
 test_that("default reference includes all functions", {
   ref <- default_reference_index(test_path("assets/reference"))
-  expect_equal(ref[[1]]$contents, paste0("`", letters[1:3], "`"))
+  expect_equal(ref[[1]]$contents, paste0("`", c(letters[1:3], "?"), "`"))
 })
