@@ -1,7 +1,7 @@
 test_that("render_rmarkdown copies image files in subdirectories", {
   skip_if_no_pandoc()
   tmp <- dir_create(file_temp())
-  pkg <- list(src_path = test_path(), dst_path = tmp)
+  pkg <- list(src_path = test_path("."), dst_path = tmp)
 
   expect_output(
     render_rmarkdown(pkg, "assets/vignette-with-img.Rmd", "test.html")
@@ -15,7 +15,7 @@ test_that("render_rmarkdown copies image files in subdirectories", {
 test_that("render_rmarkdown yields useful error", {
   skip_if_no_pandoc()
   tmp <- dir_create(file_temp())
-  pkg <- list(src_path = test_path(), dst_path = tmp)
+  pkg <- list(src_path = test_path("."), dst_path = tmp)
 
   verify_output(test_path("test-rmarkown-error.txt"), {
     render_rmarkdown(pkg, "assets/pandoc-fail.Rmd", "test.html")
